
# wauxio
v0.3.6

This library is for in-Python audio translation and proccessing.


## Installation

### PyPI
```sh
pip install wauxio
```

### GitHub
```sh
pip install git+https://github.com/wumtdev/wauxio.git
```

### Manual
Clone from github
```sh
# using https
git clone https://github.com/wumtdev/wauxio.git
# using ssh
git clone git@github.com:wumtdev/wauxio.git
```

In the environment where you need to install wauxio, install library as a local package. Specify path to cloned repository.
```sh
pip install /path/to/cloned_repo
```


## Usage
TODO: There will be guides for library usage :(

You can check examples to use and test library


## Dependencies
- `numpy` for multidimensional numeric arrays
- `wsignals` for emitting and handling events
- `miniaudio` for mp3 codec
- `soundfile` for general codec(wav, ogg, etc...)
